Skip to contents

Data frame of IDs after processing the practice data for data sufficiency and degree seeking. Provides a convenient bloc to start many of the analysis illustrated in the package articles.

Usage

baseline_mcid

Format

data.table with 76875 rows and 1 column:

mcid

Character. Anonymized student identifier that connects the four data tables, e.g., "MCID3111142897."

See also