midfieldr: Tools and Methods for Working with MIDFIELD Data in 'R'
Source:R/midfieldr-package.R
midfieldr-package.RdProvides tools in 'R' for working with undergraduate, longitudinal, student-level records modeled on the MIDFIELD database. Tools facilitate identifying academic program codes, excluding post-baccalaureate terms, excluding records for insufficient data, and assessing timely completion. The tools support the workflow of collecting programs, refining the population, constructing blocs of records for aggregation, and calculating quantitative metrics. 'midfieldr' interacts with practice data provided in the 'midfielddata' package or with any data modeled on the MIDFIELD database. The development of 'midfieldr' and 'midfielddata' was supported by the US National Science Foundation through grant numbers 1545667 and 2142087.
Author
Maintainer: Richard Layton graphdoctor@gmail.com [copyright holder]
Authors:
Richard Layton graphdoctor@gmail.com [copyright holder]
Russell Long [copyright holder]
Matthew Ohland ohland@purdue.edu [copyright holder]
Marisa Orr [copyright holder]
Susan Lord [copyright holder]
Other contributors:
US National Science Foundation [funder]