Data frame of IDs after processing the practice data for data sufficiency and degree seeking. Provides a convenient bloc to start many of the analysis illustrated in the package articles.
Format
data.table with 76875 rows and 1 column:
mcidCharacter. Anonymized student identifier that connects the four data tables, e.g., "MCID3111142897."
See also
Other case-study-data:
study_observations,
study_programs,
study_results