Skip to contents

Provides tools and demonstrates methods for working with individual undergraduate student-level records (registrar's data) in 'R'. Tools include filters for program codes, data sufficiency, and timely completion. Methods include gathering blocs of records, computing quantitative metrics such as graduation rate, and creating charts to visualize comparisons. 'midfieldr' interacts with practice data provided in the 'midfielddata' package or with any data structure modeled on the MIDFIELD database. The development of 'midfieldr' and 'midfielddata' was supported by the US National Science Foundation through grant numbers 1545667 and 2142087.

Author

Maintainer: Richard Layton graphdoctor@gmail.com [copyright holder]

Authors:

  • Richard Layton graphdoctor@gmail.com [copyright holder]

  • Russell Long [copyright holder]

  • Matthew Ohland ohland@purdue.edu [copyright holder]

  • Marisa Orr [copyright holder]

  • Susan Lord [copyright holder]

Other contributors:

  • US National Science Foundation [funder]