To a data frame keyed by student ID and containing an academic term variable, add a column that clusters terms with respect to a student's first degree term. Post-baccalaureate terms are typically excluded from the term, course, and degree data tables.
Value
Data frame with the following properties:
Data frame class is preserved. Groups and keys are not preserved.
Rows are not modified.
Columns are not modified except new columns overwrite old columns of the same name. New columns:
first_degree_term.Character. Term of a student's first baccalaureate, encodedYYYYTor, if no degree recorded,NA. Joined frommidfield_rec$term_degree.term_cluster.Character, indicating that a term belongs to one of three clusters: terms that are prior to ("pre-degree"), equal to ("first-degree"), or subsequent to ("post-first-degree") the student’s first degree term.