Usage
sort_uniq(
x,
...,
incomparables = FALSE,
MARGIN = 1,
fromLast = FALSE,
decreasing = FALSE,
na.last = FALSE
)Arguments
- x
Vector of values to be sorted with any duplicate values removed.
- ...
Not used for passing values; forces subsequent arguments to be referable only by name.
- incomparables
A vector of values. See
unique().- MARGIN
An integer. The array margin to be held fixed. Passed to
unique().- fromLast
Logical. Indicates if duplication should be considered from the last. Passed to
unique().- decreasing
Logical. Should the sort be increasing or decreasing? Passed to
sort().- na.last
Logical. Position of NA values. Passed to
sort().