Selected variables modeled on those in the course practice data for use in
package examples and articles. Sampled from an early version of the practice
data, the toy data are not a current practice data sample.
Format
data.table with 5863 rows and 12 columns keyed by student ID:
mcidCharacter, de-identified student ID. Key column.
institutionCharacter, de-identified institution name, e.g., Institution A, Institution B, etc.
termCharacter, academic year and term, format YYYYT. Key column.
courseCharacter, course name, e.g.,
Astrophysics III,Calculus For Social Science And Business,Corp Financial Rprtng 1,Environmental Sanitation II,Fitness and Wellness,Introductory Astronomy 2,Our Changing Environment, etc.abbrevCharacter, course alphabetical identifier, e.g. ENGR, MATH, ENGL. Key column.
numberCharacter, course numeric identifier, e.g. 101, 3429. Key column.
sectionCharacter, course section identifier, from one to four characters, e.g.,
1,2,01,14,001,040,785,H02,R01,300E,888R, etc.typeCharacter, predominant delivery method for this section, e.g.,
Blended,Distance Education,Face-to-Face,Online, etc.faculty_rankCharacter, academic rank of the person teaching the course, e.g.,
Assistant Professor,Associate Professor,Graduate Assistant,Visiting Faculty, etc.hours_courseNumeric, number of credit-hours for successful course completion.
gradeCharacter, course grade, e.g., A+, A, A-, B+, I, NG, etc.
discipline_midfieldCharacter, a variable for grouping courses by academic discipline assigned by the pre-2023 MIDFIELD data curator, e.g.,
Anthropology,Business,Computer Science,Engineering,Language and Literature,Mathematics,Visual and Performing Arts, etc.
See also
Other toy-data:
toy_degree,
toy_student,
toy_term