A subset of rows from the midfielddata degree table that comprises
those students from the toy_student dataset who complete a program.
A small dataset used in examples.
Format
Data frame with 193 rows and 4 columns (data.table class).
Composite key: {mcid, term_degree, cip6}.
mcidCharacter. Anonymized student identifier that connects the four data tables, e.g., "MCID3111142897."
term_degreeCharacter. Academic year and term in which a student completes their program, encoded
YYYYT.cip6Character. The 6-digit CIP code of the program that the student completes in this term.
institutionCharacter. The anonymized name of the institution the student attended in a given term, e.g., "Institution A", "Institution B", etc.
degreeCharacter. Type of degree awarded, e.g., "Bachelor of Arts in Geography", "Bachelor of Science in Finance," etc.
See also
Other toy-data:
toy_course,
toy_student,
toy_term