Selected variables modeled on those in the degree practice data for use in
package examples and articles. Sampled from an early version of the practice
data, the toy data are not a current practice data sample.
Format
data.table with 93 rows and 4 columns keyed by student ID:
mcidCharacter, de-identified student ID. Key column.
institutionCharacter, de-identified institution name, e.g., Institution A, Institution B, etc.
term_degreeCharacter, academic year and term in which a student completes their program, format YYYYT.
cip6Character, 6-digit CIP code of program in which a student is enrolled in a term. Key column.
degreeCharacter, type of degree awarded, e.g., Bachelor of Arts in Geography, Bachelor of Science in Finance, etc.
See also
Other toy-data:
toy_course,
toy_student,
toy_term