A subset of rows from the midfielddata student table. A small dataset
for use in examples.
Format
Data frame with 351 rows and 13 columns (data.table class).
Key: {mcid}.
mcidCharacter. Anonymized student identifier that connects the four data tables, e.g., "MCID3111142897."
raceCharacter. Race/ethnicity as self-reported by the student, e.g., "Asian", "Black", "Hispanic", etc.
sexCharacter. Sex as self-reported by the student, possible values are "Female", "Male", and "Unknown."
institutionCharacter. The anonymized name of the institution the student attended in a given term, e.g., "Institution A", "Institution B", etc.
transferCharacter. Transfer status, possible values are "First-Time in College", "First-Time Transfer."
hours_transferNumeric. Number of credit hours transferred (or NA).
age_descCharacter. Age group, possible values are "25 and Older", "Under 25."
us_citizenCharacter. US citizenship, possible values are "No", "Yes."
home_zipCharacter. Home ZIP code (or NA), e.g., "02056", "20170", "51301", "80129", etc.
high_schoolCharacter. Code for the last high school attended before admission (or NA), e.g., "060075", "210512", "431800", "502195", etc.
sat_mathNumeric. SAT mathematics test score (or NA).
sat_verbalNumeric. SAT reading test score (or NA).
act_compNumeric. ACT composite test score (or NA).
See also
Other toy-data:
toy_course,
toy_degree,
toy_term