Selected variables modeled on those in the student practice data for use in
package examples and articles. Sampled from an early version of the practice
data, the toy data are not a current practice data sample.
Format
data.table with 15 rows and 13 columns keyed by student ID:
mcidCharacter, de-identified student ID. Key column.
institutionCharacter, de-identified institution name, e.g., Institution A, Institution B, etc.
transferCharacter, transfer status, possible values are
First-Time in College,First-Time Transfer.hours_transferNumeric, number of credit hours transferred (or NA).
raceCharacter, race/ethnicity as self-reported by the student, e.g., Asian, Black, Hispanic, etc.
sexCharacter, sex as self-reported by the student, possible values are Female, Male, and Unknown.
age_descCharacter, age group, possible values are
25 and Older,Under 25.us_citizenCharacter, US citizenship, possible values are
No,Yes.home_zipCharacter, home ZIP code (or
NA), e.g.,02056,20170,51301,80129, etc.high_schoolCharacter, code for the last high school attended before admission (or
NA), e.g.,060075,210512,431800,502195, etc.sat_mathNumeric, SAT mathematics test score (or
NA).sat_verbalNumeric, SAT reading test score (or
NA).act_compNumeric, ACT composite test score (or
NA).
See also
Other toy-data:
toy_course,
toy_degree,
toy_term