Selected variables modeled on those in the student practice data for use in
package examples and articles. Sampled from an early version of the practice
data, the toy data are not a current practice data sample.
toy_studentdata.table with 99 rows and 4 columns keyed by student ID.
mcidCharacter, de-identified student ID.
institutionCharacter, de-identified institution name, e.g., Institution A, Institution B, etc.
raceCharacter, race/ethnicity as self-reported by the student, e.g., Asian, Black, Latine, etc.
sexcharacter, sex as self-reported by the student, possible values are Female, Male, and Unknown.
Other toy-data:
toy_course,
toy_degree,
toy_term