Selected variables modeled on those in the term practice data for use in
package examples and articles. Sampled from an early version of the practice
data, the toy data are not a current practice data sample.
Format
data.table with 1114 rows and 13 columns keyed by student ID:
mcidCharacter, de-identified student ID. Key column.
institutionCharacter, de-identified institution name, e.g., Institution A, Institution B, etc.
termCharacter, academic year and term, format YYYYT. Key column.
cip6Character, 6-digit CIP code of program in which a student is enrolled in a term, e.g.,
090101,141201,260901,420101, etc.levelCharacter, 01 Freshman, 02 Sophomore, etc. The equivalent values in the current practice data are 01 First-Year, 02-Second Year, etc.
standingCharacter, academic standing, e.g.,
Good Standing,Academic Warning, etc.coopCharacter, cooperative education term, possible values are
Yes,No.hours_termNumeric, credit hours earned in the term.
hours_term_attemptNumeric, credit hours attempted in the term.
hours_cumulNumeric, cumulative credit hours earned.
hours_cumul_attemptNumeric, cumulative credit hours attempted.
gpa_termNumeric, term grade point average.
gpa_cumulNumeric, cumulative grade point average.
See also
Other toy-data:
toy_course,
toy_degree,
toy_student